@@ -17,10 +17,12 @@ module Compass
   def shared_extension_paths
     @shared_extension_paths ||= begin
       if ENV["HOME"] && File.directory?(ENV["HOME"])
-        [File.expand_path("~/.compass/extensions")]
+        [File.join(ENV["HOME"], ".compass", "extensions")]
       else
         []
       end
+    rescue ArgumentError # If HOME is relative
+      []
     end
   end
   module_function :base_directory, :lib_directory, :shared_extension_paths
@@ -30,3 +32,6 @@ end
 %w(configuration frameworks app_integration actions compiler).each do |lib|
   require "compass/#{lib}"
 end
+
+# for rails upgrade warnings in 0.12
+require 'compass/app_integration/rails'
