@@ -1,14 +1,19 @@
 require 'test_helper'
 
 class EngineTest < Test::Unit::TestCase
-  
+  include SpriteHelper
   def setup
+    create_sprite_temp
     sprite_filename = 'squares/ten-by-ten.png'
     @images = [
        Compass::SassExtensions::Sprites::Image.new(nil, File.join(sprite_filename), {}) 
       ]
     @engine = Compass::SassExtensions::Sprites::Engine.new(100, 100, @images)
   end
+
+  def taredown
+    clean_up_sprites
+  end
   
   
   test "should have width of 100" do
